@@ -4,7 +4,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2020	PgPool Global Development Group
+ * Copyright (c) 2003-2023	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -47,19 +47,6 @@
 #define POOLKEYFILE 	".pgpoolkey"
 #define POOLKEYFILEENV "PGPOOLKEYFILE"
 
-/*
- * Brought from PostgreSQL's pg_config_manual.h.
- *
- * Maximum length for identifiers (e.g. table names, column names,
- * function names).  Names actually are limited to one less byte than this,
- * because the length must include a trailing zero byte.
- *
- * Please note that in version 2 protocol, maximum user name length is
- * SM_USER, which is 32.
- */
-#define NAMEDATALEN 64
-
-/* configuration file name */
 #define POOL_CONF_FILE_NAME "pgpool.conf"
 
 /* PCP user/password file name */
@@ -367,7 +354,6 @@ typedef enum
 #define STREAM (pool_config->backend_clustering_mode == CM_STREAMING_REPLICATION)
 #define LOGICAL (pool_config->backend_clustering_mode == CM_LOGICAL_REPLICATION)
 #define SLONY (pool_config->backend_clustering_mode == CM_SLONY)
-#define DUAL_MODE (REPLICATION || NATIVE_REPLICATION)
 #define RAW_MODE (pool_config->backend_clustering_mode == CM_RAW)
 #define SL_MODE (STREAM || LOGICAL) /* streaming or logical replication mode */
 
@@ -379,7 +365,7 @@ typedef enum
 #define Min(x, y)		((x) < (y) ? (x) : (y))
 
 
-#define MAX_NUM_SEMAPHORES		8
+#define MAX_NUM_SEMAPHORES		9
 #define CONN_COUNTER_SEM		0
 #define REQUEST_INFO_SEM		1
 #define SHM_CACHE_SEM			2
@@ -388,6 +374,7 @@ typedef enum
 #define ACCEPT_FD_SEM			5
 #define SI_CRITICAL_REGION_SEM	6
 #define FOLLOW_PRIMARY_SEM		7
+#define MAIN_EXIT_HANDLER_SEM	8	/* used in exit_hander in pgpool main process */
 #define MAX_REQUEST_QUEUE_SIZE	10
 
 #define MAX_SEC_WAIT_FOR_CLUSTER_TRANSACTION 10	/* time in seconds to keep
@@ -560,6 +547,7 @@ extern pid_t mypid;				/* parent pid */
 extern pid_t myProcPid;			/* process pid */
 extern ProcessType processType;
 extern ProcessState processState;
+extern bool	reset_query_error;	/* true if error occurs in reset queries */
 extern void set_application_name(ProcessType ptype);
 extern void set_application_name_with_string(char *string);
 extern void set_application_name_with_suffix(ProcessType ptype, int suffix);
